"""Smoke tests for src/kindex/adapters/claude_web.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_claude_web():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.claude_web")
    assert mod is not None
